from .cli import cli, __tools__
from .nmap import nmap
from .sublist3r import sublist3r
from .sherlock import sherlock
from .s3scanner import s3scanner

__all__ = ["cli", "__tools__", "nmap", "sublist3r", "sherlock", "s3scanner"]



import os

from fsociety.core.repo import GitHubRepo
from fsociety.core.menu import confirm


class cuteitRepo(GitHubRepo):
    def __init__(self):
        super().__init__(path="D4Vinci/Cuteit", 
                         install=None,
                         description="IP obfuscator made to make a malicious ip a bit cuter")

    def run(self):
        os.chdir(self.full_path)
        user_ip = input("\nEnter a ip: ").strip()
        return os.system(f"python3 Cuteit.py {user_ip}")


cuteit = cuteitRepo()
